Module: Quiver::Adapter::ActiveRecordAdapterFilterDefaults::ClassMethods

Defined in:
lib/quiver/adapter/active_record_adapter_filter.rb

Instance Method Summary collapse

Instance Method Details

#find(attr_name, opts) ⇒ Object

Raises:

  • (ArgumentError)


11
12
13
14
15
16
17
18
# File 'lib/quiver/adapter/active_record_adapter_filter.rb', line 11

def find(attr_name, opts)
  raise ArgumentError, ':on must be a table name specified as a symbol' unless opts[:on].is_a?(Symbol)
  # in the future we want to support arrays, but right now we don't need
  # it so it is hard to justify the extra time it would take
  #
  # tables = opts[:on].is_a?(Array) ? opts[:on] : [opts[:on]]
  attr_lookup_table[attr_name.to_sym] = opts[:on]
end